@a=qw/13 2 0 4 8 5 0 2 0 14 1 10 0 18 2 0 3 3 0 9 25 10/;
$^W=open(A,$0);$a=($_)=(join('',<A>)=~/\(\"(.*?)\);/s);
s;[\$\@].;;g;s;[^a-zA-Z.]; ;g;s;\s+; ;g;
${uc(pack'H6','736967')}{pack'H16','5f5f5741524e5f5f'}
=sub{$a=shift(@a)-1;print$_[0]=~/.{$a}(.)/};
s; \.;.;gs;s;(.{1,60}\s);print"\n$1";ge;
@b=("Mr.","$TPJ","saw me trying to","chmod 777,'chmod.'", 
   "He knew it was odd. Like trying to","print print$a",
   ". It must be obfuscated I said. He said see an","oct('08').",
   "No but","accept MY,APOLOGIES",
   "if you can not grok. Should anyone ask","tell THEM",
   "that the","getpeername IS","a decoy. He said","listen TO,0",
   "$a=1_21","me. I know you well Mr.","j",
   ". I do not think you will continue to","connect THE,$a",
   "real and unreal if you keep this up.","$a=1if($a=1)",
   "you want","my $a,$a=@b","advice you should","seek HELP,0,1.",
   "Dr.","syswrite MIGHT,$a,1","help you. If not he will",
   "send YOU,'TO',2","Dr.","Perl","who works for");
foreach$a(@b){$a[0]?eval$a:$#{@a=@a[$^W..$#a]}};
